/*
 * 
 *  This file is part of Sourceprojects.org Lycia Copyright 2010 noctarius
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * 
 */
package org.sourceprojects.xmlparser.internal;

import org.sourceprojects.lycia.NamespaceResolver;
import org.sourceprojects.lycia.ResourceResolver;
import org.sourceprojects.lycia.internal.dom.ResourceResolverResult;

public class ResourceResolverAdapter implements ResourceResolver {

	private final org.sourceprojects.xmlparser.ResourceResolver resolver;

	public ResourceResolverAdapter(
			final org.sourceprojects.xmlparser.ResourceResolver resolver) {

		this.resolver = resolver;
	}

	@Override
	public boolean isShowWarning() {
		return resolver.isShowWarning();
	}

	@Override
	public void setShowWarning(final boolean showWarning) {
		resolver.setShowWarning(showWarning);
	}

	@Override
	public void unregisterNamespaceResolver(final String namespaceURI) {
		resolver.unregisterNamespaceResolver(namespaceURI);
	}

	@Override
	public ResourceResolverResult resolveResource(final String type,
			final String namespaceURI, final String publicId,
			final String systemId, final String baseURI) {

		return new LSInputWrapper(resolver.resolveResource(type, namespaceURI,
				publicId, systemId, baseURI));
	}

	@Override
	public void registerNamespaceResolver(
			final NamespaceResolver namespaceResolver) {
		resolver.registerNamespaceResolver(new NamespaceResolverAdapter(
				namespaceResolver));
	}

	@Override
	public void unregisterNamespaceResolver(
			final NamespaceResolver namespaceResolver) {
		resolver.unregisterNamespaceResolver(new NamespaceResolverAdapter(
				namespaceResolver));
	}

	org.sourceprojects.xmlparser.ResourceResolver getWrappedResolver() {
		return resolver;
	}

}
